NFD+model+apps+helper+tests: Upgrade NFD and related changes

Based on NFD:commit:2fc649bfc67b93b4191cfbee5bcd70330bfb48f0 (version 0.3.4)

Change-Id: I89f5182600467171797af4f8f83e1edffe14ad95
Refs: #3125
diff --git a/tests/other/ndn-test.sh b/tests/other/ndn-test.sh
index f260de4..fac2756 100755
--- a/tests/other/ndn-test.sh
+++ b/tests/other/ndn-test.sh
@@ -15,10 +15,10 @@
 
 echo "CS size = " $size, "interest rate = " $rate
 
-# using broadcast forwarding strategy
-echo "Using broadcast forwarding strategy.."
+# using multicast forwarding strategy
+echo "Using multicast forwarding strategy.."
 
-../../../waf --run ndn-test --command-template="%s --old-cs=ns3::ndn::cs::Lru --cs-size=${size} --rate=${rate} --sim-time=${sim_time} --pit=$(true) --strategy="/localhost/nfd/strategy/broadcast" "
+../../../waf --run ndn-test --command-template="%s --old-cs=ns3::ndn::cs::Lru --cs-size=${size} --rate=${rate} --sim-time=${sim_time} --pit=$(true) --strategy="/localhost/nfd/strategy/multicast" "
 
 echo
 
@@ -41,10 +41,10 @@
 
 echo "CS size = " $size, "interest rate = " $rate
 
-# using broadcast forwarding strategy
-echo "Using broadcast forwarding strategy.."
+# using multicast forwarding strategy
+echo "Using multicast forwarding strategy.."
 
-../../../waf --run ndn-test --command-template="%s --cs-size=${size} --rate=${rate} --strategy="/localhost/nfd/strategy/broadcast" --sim-time=${sim_time}"
+../../../waf --run ndn-test --command-template="%s --cs-size=${size} --rate=${rate} --strategy="/localhost/nfd/strategy/multicast" --sim-time=${sim_time}"
 
 echo